@@ -13,7 +13,7 @@ use DBIx::Class::Async::Storage;
 use DBIx::Class::Async::TxnGuard;
 use DBIx::Class::Async::ResultSet;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 =head1 NAME
 
@@ -21,7 +21,7 @@ DBIx::Class::Async::Schema - Asynchronous Schema for DBIx::Class::Async
 
 =head1 VERSION
 
-Version 0.11
+Version 0.12
 
 =cut
 
@@ -560,6 +560,78 @@ sub DESTROY {
     $self->disconnect;
 }
 
+=head1 PERFORMANCE OPTIMISATION
+
+=head2 Resolving the N+1 Query Problem
+
+One of the most common performance bottlenecks in ORMs is the "N+1" query pattern. This occurs when you fetch a set of rows and then loop through them to fetch a related row for each member of the set.
+
+In an asynchronous environment, this is particularly costly due to the overhead of message passing between the main process and the database worker pool.
+
+C<DBIx::Class::Async::Schema> resolves this by supporting the standard C<DBIx::Class> B<prefetch> attribute.
+
+
+
+=head3 The Slow Way (N+1 Pattern)
+
+In this example, if there are 50 orders, this code will perform 51 database round-trips.
+
+    my $orders = await $async_schema->resultset('Order')->all;
+
+    foreach my $order (@$orders) {
+        # Each call here triggers a NEW asynchronous find() query to a worker
+        my $user = await $order->user;
+        say "Order for: " . $user->name;
+    }
+
+=head3 The Optimised Way (Eager Loading)
+
+By using C<prefetch>, you instruct the worker to perform a C<JOIN> in the background. The related data is serialised and sent back in the primary payload. The library then automatically hydrates the nested data into blessed Row objects.
+
+    # Only ONE database round-trip for any number of orders
+    my $orders = await $async_schema->resultset('Order')->search(
+        {},
+        { prefetch => 'user' }
+    );
+
+    foreach my $order (@$orders) {
+        # This returns a resolved Future immediately from the internal cache.
+        # No extra SQL or worker communication is required.
+        my $user = await $order->user;
+        say "Order for: " . $user->name;
+    }
+
+=head2 Complex Prefetching
+
+The hydration logic is recursive. You can prefetch multiple levels of relationships or multiple independent relationships simultaneously.
+
+    my $rs = $async_schema->resultset('Order')->search({}, {
+        prefetch => [
+            { user => 'profile' }, # Nested: Order -> User -> Profile
+            'status_logs'          # Direct: Order -> Logs
+        ]
+    });
+
+    my $orders = await $rs->all;
+
+    # All the following are available instantly:
+    my $user    = await $orders->[0]->user;
+    my $profile = await $user->profile;
+
+=head2 Implementation Details
+
+=over 4
+
+=item * B<Automation>: Prefetched data is automatically cached in an internal C<_prefetched> slot within the C<DBIx::Class::Async::Row> object during inflation.
+
+=item * B<Transparency>: The relationship accessors generated by C<Row.pm> transparently check this cache before attempting a lazy-load via the worker pool.
+
+=item * B<Efficiency>: By collapsing multiple queries into one, you significantly reduce the latency introduced by inter-process communication (IPC) and database contention.
+
+=back
+
+=cut
+
 =head1 SEE ALSO
 
 =over 4
